import React, { useCallback, useState } from 'react';
import { FlatList } from 'react-native';
import { useFocusEffect } from '@react-navigation/native';

import { Header, PageWrapper, Loading } from '../../../../components';
import { storage, StoreType } from '../../../../storage';

import { Profile } from '../Components/Profile';

import type { Ranking } from '..';
const InHistoryScreen = () => {
  const [historyRanking, setHistoryRanking] = useState<Ranking[]>([]);
  const [isLoading, setIsLoading] = useState(true);

  useFocusEffect(
    useCallback(() => {
      const fetchRanking = async () => {
        const inHistory: string = storage.get('inHistoryRanking', StoreType.STRING) as string;
        setHistoryRanking(
          JSON.parse(inHistory).sort((a: Ranking, b: Ranking) => b.score_nm - a.score_nm)
        );
        setIsLoading(false);
      };

      fetchRanking();
    }, [])
  );

  if (isLoading) return <Loading />;

  return (
    <PageWrapper>
      <FlatList
        showsVerticalScrollIndicator={false}
        ListHeaderComponent={<Header label="In History" />}
        data={historyRanking}
        keyExtractor={(item) => item.user_id.toString()}
        renderItem={({ item, index }) => (
          <Profile
            key={index}
            index={index}
            first_name={item.first_name}
            last_name={item.last_name}
            avatar={item.avatar}
            date_of_birth={item.age}
            homebase_flag={item.flag1}
            homebase2_flag={item.flag2}
            tbt_score={item.score_tbt}
            score={[
              item.score_nm,
              item.score_dare,
              item.score_un,
              item.score_unp,
              item.score_tcc,
              item.score_yes,
              item.score_slow,
              item.score_whs,
              item.score_kye
            ]}
            auth={item.auth}
            badge_1281={item.badge_1281}
            badge_un={item.badge_un}
          />
        )}
        onEndReachedThreshold={0.1}
      />
    </PageWrapper>
  );
};

export default InHistoryScreen;
