import React, { useCallback, useState } from 'react';
import { FlatList, View, Text } from 'react-native';
import { useFocusEffect } from '@react-navigation/native';

import HorizontalSelect from '../Components/HorizontalSelect';

import { Header, Loading, PageWrapper } from '../../../../components';
import { getMastersByType } from '../../../../database/unMastersService';
import type { Master, TypeData } from '../../../../database/unMastersService';

const UNMastersScreen = () => {
  const [selectedType, setSelectedType] = useState<TypeData | null>(null);
  const [masters, setMasters] = useState<Master[] | null>([]);
  const [isLoading, setIsLoading] = useState(true);

  useFocusEffect(
    useCallback(() => {
      const fetchType = async () => {
        const data = getMastersByType(selectedType?.type || 1);
        setMasters(data);
        setIsLoading(false);
      };

      fetchType();
    }, [])
  );

  if (isLoading) return <Loading />;

  return (
    <PageWrapper>
      <Header label={'UN Masters'} />
      <HorizontalSelect selectedType={(type) => setSelectedType(type)} />
      <FlatList
        maxToRenderPerBatch={20}
        data={masters}
        renderItem={({ item }) => (
          <View style={{ borderStyle: 'solid', borderWidth: 1, borderColor: 'red' }}>
            <Text>{item.age}</Text>
          </View>
        )}
      />
    </PageWrapper>
  );
};

export default UNMastersScreen;
